@@ -3,7 +3,7 @@ import pynput.keyboard as kb
 from keyboard import is_pressed
 
 
-@click.command(help='hold a keyboard key')
+@click.command(short_help='Hold a keyboard key')
 @click.argument('key', metavar='<key>', type=click.STRING)
 def keyhold(key):
     k = kb.Controller()
