@@ -3,6 +3,38 @@ from os import system
 from time import sleep
 from datetime import datetime
 from re import search
+from typing import List, Tuple
+
+
+def reg_crono(h:int, m:int, s:int) -> Tuple[int, int, int]:
+    """
+    Regressive clocker.
+
+    Takes hrs,mts,scs and regress then. (-1sec)
+    Return the values regressed.
+    """
+    if s > 0:
+        s -= 1
+    else:
+        if m > 0:
+            m -= 1
+            s = 60
+        else:
+            if h > 0:
+                h -= 1
+                m = 60
+    return h, m, s
+
+
+def time_format(*args: int) -> List:
+    """
+    Take an int and format it to time display:
+    1 -> 01, 7 -> 07, 12 -> 12
+    """
+    fmt = list(map(lambda x:
+                         '0' + str(x) if len(str(x)) == 1
+                         else str(x), args))
+    return fmt
 
 
 @click.group('sched', help='Schedule tasks at the command line level')
@@ -17,10 +49,10 @@ def sched():
 @click.argument('s', metavar='<seconds>', type=click.INT, required=False, default=0)
 def run(command, s, m, h):
     """\b
-       Run commands repetitively at a given interval starting from
-       current moment.
-        \b
-       Example: lash sched run "help" 0 0 5 """
+       Run the command repetitively at a given interval.
+
+       \b
+       Example: run "help" 0 0 5 """
     try:
         if h <= 0 and m <= 0 and s <= 0:
             raise Exception('Error: Time delay is not defined')
@@ -28,10 +60,13 @@ def run(command, s, m, h):
         print(e)
     t = h * 3600 + m * 60 + s  # Converting to seconds
     while True:
+        h2, m2, s2 = h, m, s
         for i in range(0, t):
-            print(f'Time remaining: {(t - i) // 60 // 60}h {(t - i) // 60}m {t - i}s ', end="\r")
+            h2, m2, s2 = reg_crono(h2, m2, s2)
+            fh, fm, fs = time_format(h2, m2, s2)
+            print(f'Time remaining: {fh}:{fm}:{fs}', end="\r")
             sleep(1)
-        print(f'Time remaining: 0h 0m 0s ', end="\r")
+        print(f'Time remaining: 00:00:00 ', end="\r")
         system(command=command)
         print()
 
@@ -42,18 +77,20 @@ def run(command, s, m, h):
 @click.argument('m', metavar='<minutes>', type=click.INT, required=False, default=0)
 @click.argument('s', metavar='<seconds>', type=click.INT, required=False, default=0)
 def wait(command, h, m, s):
-    """\b
-        Wait x time, run a task once and exit
+    """
+        Wait x time, run a command once and exit.
+
         \b
-        Example: lash sched wait "help" 0 0 10
+        Example: wait "help" 0 0 10
     """
     # assert h <= 0 and m <= 0 and s <= 0, 'Error: Time delay is not defined'
     t = h * 3600 + m * 60 + s  # Converting to seconds
     for i in range(0, t):
+        h, m, s = reg_crono(h, m, s)
+        fh, fm, fs = time_format(h, m, s)
+        print(f'Time remaining: {fh}:{fm}:{fs}', end="\r")
         sleep(1)
-        print(f'Time remaining: {(t - i) // 60 // 60}h {(t - i) // 60}m {t - i}s ', end="\r")
-    sleep(1)
-    print(f'Time remaining: 0h 0m 0s ', end="\r")
+    print(f'Time remaining: 00:00:00 ', end="\r")
     system(command=command)
 
 
@@ -62,19 +99,17 @@ def wait(command, h, m, s):
 @click.argument('command', metavar='<command>', type=click.STRING)
 def exec(time, command):
     """\b
-        Execute a task from determined moment of day
+        Execute a command from determined moment of day.
+
         \b
         The time need to have this syntax: 10:30:0
-        Command example exec 10:30:0 "help"
+        Example: exec 15:25:0 "help"
     """
-    if not search('\d\d:\d\d:\d', time):
-        return print('ERROR sytax incorrect, try use 10:30:0 with time')
-    if time[-1] and time[-2] == 0:
+    if not search('\d:\d:\d', time):
+        return print('ERROR sytax incorrect, try use 10:30:0, 1:4:5 with time')
+    if time[-1] and time[-2] == '0':
         time = time[:-1]
-    while True:
-        if f'{datetime.now().hour}:{datetime.now().minute}:{datetime.now().second}' == time:
-            system(command=command)
-            return
-        else:
-            print(f' Waiting {time} -> {datetime.now().hour}:{datetime.now().minute}:{datetime.now().second}', end='\r')
-
+        print(time)
+    while f'{datetime.now().hour}:{datetime.now().minute}:{datetime.now().second}' != time:
+        print(f' Waiting {datetime.now().hour}:{datetime.now().minute}:{datetime.now().second} -> {time}', end='\r')
+    system(command=command)
